/*
** ADM-XRC Series Driver
**
** (C) Copyright 2001-2004 Alpha Data
**
** info.c - IOCTL handlers for returning information about a card.
**
** ----------------------------------------------------------------------------
*/

#include "platform.h"
#include "device.h"
#include "ioctl_struct.h"
#include "info.h"
#include "driver_ver.h"

OS_STATUS
ADMXRC_GetBankInfo(
  DeviceContext* pDevCtx,
  OS_IO_REQUEST* req)
{
  ADMXRC_IOCTLS_GETBANKINFO* in;
  ADMXRC_IOCTLS_GETBANKINFO* out;
  unsigned long              index;

  in = (ADMXRC_IOCTLS_GETBANKINFO*) req->param.inBuf;
  if (in == NULL || req->param.inSize != sizeof(in->in)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  out = (ADMXRC_IOCTLS_GETBANKINFO*) req->param.outBuf;
  if (out == NULL || req->param.outSize != sizeof(out->out)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  
  index = in->in.index;
  if (index >= pDevCtx->info.cardInfo.numRamBank) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  
  out->out.type = pDevCtx->info.bankInfo[index].type;
  out->out.width = pDevCtx->info.bankInfo[index].width;
  out->out.size = pDevCtx->info.bankInfo[index].size;
  out->out.fitted = pDevCtx->info.bankInfo[index].fitted;

  req->status.length = sizeof(out->out);

  return OS_STATUS_SUCCESS;
}

OS_STATUS
ADMXRC_GetCardInfo2(
  DeviceContext* pDevCtx,
  OS_IO_REQUEST* req)
{
  ADMXRC_IOCTLS_GETCARDINFO2* ioctl;

  ioctl = (ADMXRC_IOCTLS_GETCARDINFO2*) req->param.outBuf;
  if (ioctl == NULL || req->param.outSize != sizeof(ioctl->out)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }

  ioctl->out.cardId = pDevCtx->info.cardInfo.cardId;
  ioctl->out.serialNum = pDevCtx->info.cardInfo.serialNum;
  ioctl->out.boardType = pDevCtx->info.cardInfo.boardType;
  ioctl->out.fpgaType = pDevCtx->info.cardInfo.fpgaType;
  ioctl->out.numClock = pDevCtx->info.cardInfo.numClock;
  ioctl->out.numDmaChan = pDevCtx->info.cardInfo.numDmaChan;
  ioctl->out.numRamBank = pDevCtx->info.cardInfo.numRamBank;
  ioctl->out.numSpace = pDevCtx->info.cardInfo.numSpace;
  ioctl->out.ramBanksFitted = pDevCtx->info.cardInfo.ramBanksFitted;
  ioctl->out.boardRevision = pDevCtx->info.cardInfo.boardRevision;
  ioctl->out.logicRevision = pDevCtx->info.cardInfo.logicRevision;

  req->status.length = sizeof(ioctl->out);

  return OS_STATUS_SUCCESS;
}

OS_STATUS
ADMXRC_GetSpaceInfo(
  DeviceContext* pDevCtx,
  ClientContext* pClCtx,
  OS_IO_REQUEST* req)
{
  ADMXRC_IOCTLS_GETSPACEINFO* in;
  ADMXRC_IOCTLS_GETSPACEINFO* out;
  unsigned long               index;

  in = (ADMXRC_IOCTLS_GETSPACEINFO*) req->param.inBuf;
  if (in == NULL || req->param.inSize != sizeof(in->in)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  out = (ADMXRC_IOCTLS_GETSPACEINFO*) req->param.outBuf;
  if (out == NULL || req->param.outSize != sizeof(out->out)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  
  index = in->in.index;
  if (index >= pDevCtx->info.cardInfo.numSpace) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  out->out.virtualBase = pClCtx->spaceInfo[index].virtualBase;
  out->out.virtualSize = pClCtx->spaceInfo[index].virtualSize;
  out->out.physicalBase = pDevCtx->info.spaceInfo[index].physicalBase;
  out->out.localBase = pDevCtx->info.spaceInfo[index].localBase;
  out->out.localSize = pDevCtx->info.spaceInfo[index].localSize;

  req->status.length = sizeof(out->out);

  return OS_STATUS_SUCCESS;
}

OS_STATUS 
ADMXRC_GetVersionInfo(
  DeviceContext* pDevCtx,
  OS_IO_REQUEST* req)
{
  ADMXRC_IOCTLS_GETVERSIONINFO* ioctl;

  ioctl = (ADMXRC_IOCTLS_GETVERSIONINFO*) req->param.outBuf;
  if (ioctl == NULL || req->param.outSize != sizeof(ioctl->out)) {
    return OS_MAKE_STATUS(ADMXRC2_INVALID_PARAMETER);
  }
  
  ioctl->out.major = ADMXRC_DRIVER_MAJORVER;
  ioctl->out.minor = ADMXRC_DRIVER_MINORVER;

  req->status.length = sizeof(ioctl->out);
  
  return OS_STATUS_SUCCESS;
}

